@@ -1,7 +1,6 @@
-{-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE OverloadedStrings, DeriveDataTypeable #-}
 module Network.HTTP.Types.Status
-(
-  Status(..)
+( Status(..)
 , mkStatus
 , status100
 , continue100
@@ -35,6 +34,8 @@ module Network.HTTP.Types.Status
 , useProxy305
 , status307
 , temporaryRedirect307
+, status308
+, permanentRedirect308
 , status400
 , badRequest400
 , status401
@@ -98,10 +99,10 @@ module Network.HTTP.Types.Status
 , statusIsRedirection
 , statusIsClientError
 , statusIsServerError
-)
-where
+) where
 
 import qualified Data.ByteString as B
+import Data.Typeable
 
 -- | HTTP Status.
 --
@@ -112,11 +113,9 @@ import qualified Data.ByteString as B
 --
 -- Note that the Show instance is only for debugging.
 data Status
-    = Status {
-        statusCode :: Int
-      , statusMessage :: B.ByteString
-      }
-    deriving (Show)
+    = Status { statusCode :: Int
+             , statusMessage :: B.ByteString
+             } deriving (Show, Typeable)
 
 instance Eq Status where
     Status { statusCode = a } == Status { statusCode = b } = a == b
@@ -125,48 +124,53 @@ instance Ord Status where
     compare Status { statusCode = a } Status { statusCode = b } = a `compare` b
 
 instance Enum Status where
-	fromEnum = statusCode
-	toEnum 100 = status100
-	toEnum 101 = status101
-	toEnum 200 = status200
-	toEnum 201 = status201
-	toEnum 202 = status202
-	toEnum 203 = status203
-	toEnum 204 = status204
-	toEnum 205 = status205
-	toEnum 206 = status206
-	toEnum 300 = status300
-	toEnum 301 = status301
-	toEnum 302 = status302
-	toEnum 303 = status303
-	toEnum 304 = status304
-	toEnum 305 = status305
-	toEnum 307 = status307
-	toEnum 400 = status400
-	toEnum 401 = status401
-	toEnum 402 = status402
-	toEnum 403 = status403
-	toEnum 404 = status404
-	toEnum 405 = status405
-	toEnum 406 = status406
-	toEnum 407 = status407
-	toEnum 408 = status408
-	toEnum 409 = status409
-	toEnum 410 = status410
-	toEnum 411 = status411
-	toEnum 412 = status412
-	toEnum 413 = status413
-	toEnum 414 = status414
-	toEnum 415 = status415
-	toEnum 416 = status416
-	toEnum 417 = status417
-	toEnum 500 = status500
-	toEnum 501 = status501
-	toEnum 502 = status502
-	toEnum 503 = status503
-	toEnum 504 = status504
-	toEnum 505 = status505
-	toEnum c   = mkStatus c B.empty
+    fromEnum = statusCode
+    toEnum 100 = status100
+    toEnum 101 = status101
+    toEnum 200 = status200
+    toEnum 201 = status201
+    toEnum 202 = status202
+    toEnum 203 = status203
+    toEnum 204 = status204
+    toEnum 205 = status205
+    toEnum 206 = status206
+    toEnum 300 = status300
+    toEnum 301 = status301
+    toEnum 302 = status302
+    toEnum 303 = status303
+    toEnum 304 = status304
+    toEnum 305 = status305
+    toEnum 307 = status307
+    toEnum 308 = status308
+    toEnum 400 = status400
+    toEnum 401 = status401
+    toEnum 402 = status402
+    toEnum 403 = status403
+    toEnum 404 = status404
+    toEnum 405 = status405
+    toEnum 406 = status406
+    toEnum 407 = status407
+    toEnum 408 = status408
+    toEnum 409 = status409
+    toEnum 410 = status410
+    toEnum 411 = status411
+    toEnum 412 = status412
+    toEnum 413 = status413
+    toEnum 414 = status414
+    toEnum 415 = status415
+    toEnum 416 = status416
+    toEnum 417 = status417
+    toEnum 428 = status428
+    toEnum 429 = status429
+    toEnum 431 = status431
+    toEnum 500 = status500
+    toEnum 501 = status501
+    toEnum 502 = status502
+    toEnum 503 = status503
+    toEnum 504 = status504
+    toEnum 505 = status505
+    toEnum 511 = status511
+    toEnum c   = mkStatus c B.empty
 
 -- | Create a Status from status code and message.
 mkStatus :: Int -> B.ByteString -> Status
@@ -300,6 +304,14 @@ status307 = mkStatus 307 "Temporary Redirect"
 temporaryRedirect307 :: Status
 temporaryRedirect307 = status307
 
+-- | Permanent Redirect 308
+status308 :: Status
+status308 = mkStatus 308 "Permanent Redirect"
+
+-- | Permanent Redirect 308
+permanentRedirect308 :: Status
+permanentRedirect308 = status308
+
 -- | Bad Request 400
 status400 :: Status
 status400 = mkStatus 400 "Bad Request"
